/***************************************************************************//**
 *   @file   ADN2850.h
 *   @brief  Header file of ADN2850 Driver.
 *   @author Dan Nechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 559
*******************************************************************************/
#ifndef __ADN2850_H__
#define __ADN2850_H__

/*****************************************************************************/
/* ADN2850                                                                    */
/*****************************************************************************/

/* ADN2850 GPIO */
#define ADN2850_RESET_OUT   GPIO1_PIN_OUT
#define ADN2850_RESET_LOW   GPIO1_PIN_LOW
#define ADN2850_RESET_HIGH  GPIO1_PIN_HIGH
#define ADN2850_WP_OUT      GPIO2_PIN_OUT
#define ADN2850_WP_LOW      GPIO2_PIN_LOW
#define ADN2850_WP_HIGH     GPIO2_PIN_HIGH
#define ADN2850_RDY_IN      GPIO3_PIN_IN
#define AD2859_RDY_STATUS   GPIO3_PIN_STATE

/* ADN2850 Intructions */
#define ADN2850_NOP_CMD                    0x00 // Do nothing.
#define ADN2850_RESTORE_RDAC_CMD           0x01 // Restore EEMEM content to RDAC.
#define ADN2850_STORE_RDAC_CMD             0x02 // Store RDAC setting to EEMEM.
#define ADN2850_WRITE_EEM_CMD              0x03 // Store RDAC setting or user data to EEMEM.
#define ADN2850_DECREMENT_6dB_CMD          0x04 // Decrement by 6 dB.
#define ADN2850_DECREMENT_6dB_ALL_CMD      0x05 // Decrement all by 6 dB.
#define ADN2850_DECREMENT_1STEP_CMD        0x06 // Decrement by one step.
#define ADN2850_DECREMENT_1STEP_ALL_CMD    0x07 // Decrement all by one step.
#define ADN2850_RESET_RDACS_CMD            0x08 // Reset EEMEM content to RDAC.
#define ADN2850_READ_EEM_CMD               0x09 // Read EEMEM content from SDO.
#define ADN2850_READ_RDAC_CMD              0x0A // Read RDAC wiper setting from SDO.
#define ADN2850_WRITE_RDAC_CMD             0x0B // Write data to RDAC.
#define ADN2850_INCREMENT_6dB_CMD          0x0C // Increment by 6 dB.
#define ADN2850_INCREMENT_6dB_ALL_CMD      0x0D // Increment all by 6 dB.
#define ADN2850_INCREMENT_1STEP_CMD        0x0E // Increment by one step.
#define ADN2850_INCREMENT_1STEP_ALL_CMD    0x0F // Increment all by one step.

/* EEMEM Address Map */
#define ADN2850_RDAC1                      0x00
#define ADN2850_RDAC2                      0x01
#define ADN2850_USER1                      0x02
#define ADN2850_USER2                      0x03
#define ADN2850_USER3                      0x04
#define ADN2850_USER4                      0x05
#define ADN2850_USER5                      0x06
#define ADN2850_USER6                      0x07
#define ADN2850_USER7                      0x08
#define ADN2850_USER8                      0x09
#define ADN2850_USER9                      0x0A
#define ADN2850_USER10                     0x0B
#define ADN2850_USER11                     0x0C
#define ADN2850_USER12                     0x0D
#define ADN2850_USER13                     0x0E
#define ADN2850_RWB1_TOLERANCE             0x0F

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/

/* Initialize the communication with the device. */
unsigned char ADN2850_Init(void);

/* Send a command to the device. It will transmit 3 bytes. */
void ADN2850_SendCommand(unsigned char command, 
                         unsigned char address, 
                         unsigned short Data);

/* Read from register or from EEMEM. */
unsigned short ADN2850_Read(unsigned char readSource, unsigned char address);

/* A subtle feature of the ADN2850 is that a subsequent CS strobe, without 
clockand data, repeats a previous command. */
void ADN2850_RepeatLastCMD(void);

/* Determines the programmed output resistance between Bx and Wx terminal. */
unsigned short ADN2850_OhmConversion(unsigned long rawData);

#endif	// ADN2850_H_
